OC.L10N.register(
    "calendar",
    {
    "Calendar" : "日曆",
    "Today" : "今天",
    "Day" : "日",
    "Week" : "星期",
    "Month" : "月",
    "Download" : "下載",
    "Delete" : "刪除",
    "Share link" : "分享連結",
    "Share with users or groups" : "共享于用戶或組別",
    "can edit" : "可編輯",
    "New calendar" : "新日曆",
    "Cancel" : "取消",
    "Automatic" : "自動",
    "Email" : "電郵",
    "Unknown" : "未知",
    "never" : "永不",
    "Repeat" : "重複",
    "Monday" : "星期一",
    "More" : "更多",
    "Save" : "儲存",
    "Update" : "更新",
    "Personal" : "個人",
    "Attendees" : "出席者",
    "Reminders" : "提示",
    "Close" : "關閉",
    "Week {number} of {year}" : "{year} 年的第 {number} 週",
    "Daily" : "每日",
    "Weekly" : "每星期",
    "today" : "今日",
    "Location" : "位置",
    "Description" : "描述",
    "Mail" : "郵件",
    "Play" : "播放"
},
"nplurals=1; plural=0;");
